# This interfaces with upgradegui, using it to display the status on the
# screen.

import struct
import os
import gzip

DEBUG = False

# The file handle to the upgrade gui program.
ugp = None

def init():
    global ugp
    ugp = os.popen("/usr/bin/upgradegui", "w")
    os.environ['UPGRADEGUI'] = str(ugp.fileno())

def close():
    if ugp is None:
        return
    
    ugp.flush()
    ugp.close()

def screen(name):
    """
    Show the named screen.
    """

    if ugp is None:
        return

    try:
        gzf = gzip.GzipFile("/usr/update_manager/screens/%s.screen.gz" % name, "r")
    except:
        return
        
    while True:
        data = gzf.read(65536)
        if not data:
            break
        ugp.write(data)

    ugp.flush()
    gzf.close()
    
def progress(amount, total):

    ugp.write("P")
    ugp.write(struct.pack("II", amount, total))
    ugp.flush()
              

def message(message, color):
    try:
        ugp.write(struct.pack(">cH", 'D', color))
        ugp.write(message.decode("base64").decode("zlib"))
        ugp.flush()
    except:
        if DEBUG:
            raise

def phase1():
    screen("upgrading")

def phase2():
    screen("upgrading2")

def flash_full():
    screen("flash_full")

def bad_package():
    screen("bad_package")

def wrong_sign():
    screen("wrong_hw_version")

def wrong_version():
    screen("wrong_version")

def error():
    screen("error")

        
def success():
    screen("success")
    
